@@ -2,6 +2,7 @@ dispMUA.arDispMUAAllocation["f"] =
 {
   "firewall notification system" : [ "astaro.png" , "http://www.astaro.de/" ] ,
   "flicks softwares ocxmail" : [ "ocxmail.png" , "http://www.flicks.com/prod.htm#ocxmail" ] ,
+  "fbm communication server" : [ "feedbackmanager.png" , "http://www.feedbackmanager.de/" ] ,
   "futureshop mail system" : [ "futurespirits.png" , "http://www.future-s.com/" ] ,
   "fr3ddie's forte agent" : [ "fr3ddie.png" , "http://www.fr3ddie.it/software/software.html" ] ,
   "first-coffee mailer" : [ "first-coffee.png" , "http://www.first-coffee.com/" ] ,
@@ -14,6 +15,7 @@ dispMUA.arDispMUAAllocation["f"] =
   "friend mailer" : [ "friend-mailer.png" , "http://www.ava-soft.com/products/fm/" ] ,
   "freecity gmbh" : [ "freecity.png" , "http://webmail.freecity.de/" ] ,
   "fuzzy admail" : [ "fuzzy_admail.png" , "http://www.fuzzy.com.br/" ] ,
+  "fuman mailer" : [ "future-management.png" , "http://www.continue.de/" ] ,
   "freemails.ch" : [ "freemails_ch.png" , "http://www.freemails.ch/" ] ,
   "fotka mailer" : [ "fotka.png" , "http://www.fotka.pl/" ] ,
   "finalbuilder" : [ "finalbuilder_com.png" , "http://www.finalbuilder.com/" ] ,
@@ -24,9 +26,12 @@ dispMUA.arDispMUAAllocation["f"] =
   "forte agent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
   "fx-service" : [ "fx-service.png" ] ,
   "ftk mailer" : [ "ftk-mailer.png" , "http://www.fotokasten.de/" ] ,
+  "fromwap.ru" : [ "fromwap_ru.png" , "http://www.fromwap.ru/" ] ,
   "freeweb.hu" : [ "freeweb_hu.png" , "http://freeweb.hu/" ] ,
   "forteagent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
+  "formmailer" : [ "formmailer.png" , "http://www.formmailer.com/" ] ,
   "firstclass" : [ "firstclass.png" , "http://www.firstclass.com/" ] ,
+  "felamimail" : [ "felamimail.png" , "http://www.phpgroupware.org/" ] ,
   "futurelab" : [ "futurelab.png" , "http://www.futurelab.com/" ] ,
   "fotovista" : [ "fotovista_com.png" , "http://www.fotovista.com/" ] ,
   "feedblitz" : [ "feedblitz.png" , "http://www.feedblitz.com/" ] ,
@@ -36,7 +41,7 @@ dispMUA.arDispMUAAllocation["f"] =
   "flyspray" : [ "flyspray.png" , "http://flyspray.org/" ] ,
   "flexmail" : [ "flexmail.png" , "http://www.pocketinformant.com/products_info.php?p_id=mail" ] ,
   "fletmail" : [ "fletmail.png" , "http://www.pancho.dk/fletmail/" ] ,
-  "fishbowl" : [ "fishbowl.png" , "" ] ,
+  "fishbowl" : [ "fishbowl.png" , "http://www.fishbowl.com/" ] ,
   "firepass" : [ "f5.png" , "http://www.f5.com/products/firepass/" ] ,
   "favo.org" : [ "favo_org.png" , "http://www.favo.org/" ] ,
   "fastmomi" : [ "fastweb_it.png" , "http://www.fastweb.it/" ] ,
