@@ -10,6 +10,7 @@ dispMUA.arDispMUAAllocation["g"] =
   "gordano messaging" : [ "gordano_ms.png" , "http://www.gordano.com/products/" ] ,
   "gimp useless mail" : [ "gimp.png" , "http://www.gimp.org/" ] ,
   "gaz via vbulletin" : [ "vbulletin.png" , "http://www.vbulletin.com/" ] ,
+  "general wireless" : [ "mobispine.png" , "http://www.mobispine.com/" ] ,
   "geminisoft pimmy" : [ "pimmy.png" , "http://www.geminisoft.com/" ] ,
   "gigi's own news" : [ "gon.png" , "http://gon.sourceforge.net/" ] ,
   "groupware aipo" : [ "aipo.png" , "http://aipostyle.com/" ] ,
@@ -29,8 +30,10 @@ dispMUA.arDispMUAAllocation["g"] =
   "gsm-inform" : [ "gsm-inform.png" , "http://gsm-inform.ru/" ] ,
   "goowy mail" : [ "goowy_mail.png" , "http://www.goowy.com/" ] ,
   "gincko lab" : [ "gincko.png" , "http://gincko-lab.com/" ] ,
+  "genie-soft" : [ "genie-soft.png" , "http://www.genie-soft.com/" ] ,
   "gandi mail" : [ "gandi_mail.png" , "http://www.gandi.net/domain/mail" ] ,
   "groupwise" : [ "groupwise.png" , "http://www.novell.com/products/groupwise/" ] ,
+  "goodemail" : [ "goodemail_cn.png" , "http://www.goodemail.cn/" ] ,
   "globomail" : [ "globomail.png" , "http://webmail.globo.com/" ] ,
   "gedifmail" : [ "gedif.png" , "http://www.gedif.de/" ] ,
   "gatormail" : [ "gatormail.png" , "http://sourceforge.net/projects/gatormail/" ] ,
@@ -44,6 +47,7 @@ dispMUA.arDispMUAAllocation["g"] =
   "golded+" : [ "golded-plus.png" , "http://golded-plus.sourceforge.net/" ] ,
   "gnumail" : [ "gnumail.png" , "http://www.collaboration-world.com/gnumail" ] ,
   "gnspool" : [ "gnspool.png" , "http://www.freshports.org/japanese/gn-gnspool/" ] ,
+  "gmx.com" : [ "gmx.png" , "http://www.gmx.com/" ] ,
   "genexus" : [ "genexus.png" , "http://www.genexus.com/" ] ,
   "gemini/" : [ "gemini.png" , "http://www.intellegit.com/software/gemini/" ] ,
   "geeklog" : [ "geeklog.png" , "http://www.geeklog.net/" ] ,
