@@ -31,6 +31,7 @@ dispMUA.arDispMUAAllocation["message-id"] =
   "@relay.skynet.be>" : [ "skynet_be.png" , "http://www.skynet.be/" , "skynet Belgacom" ] ,
   "@merter-musek.lu>" : [ "musek_lu.png" , "http://www.merter-musek.lu/" , "Merter Musek" ] ,
   ".thestandard.com>" : [ "thestandard_com.png" , "http://www.thestandard.com/" , "The Industry Standard" ] ,
+  ".mailinblack.com>" : [ "mailinblack.png" , "http://mailinblack.com/" , "MAILinBlack" ] ,
   ".kundenserver.de>" : [ "1und1.png" , "http://www.1und1.de/" , "1&1" ] ,
   ".auctionweb.info>" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" , "AuctionWeb" ] ,
   "@poczta.jaaz.pl>" : [ "jaaz_pl.png" , "http://www.jaaz.pl/" , "jaaz.pl" ] ,
@@ -38,6 +39,7 @@ dispMUA.arDispMUAAllocation["message-id"] =
   "@googlemail.com>" : [ "google_googlemail.png" , "http://www.googlemail.com/" , "Google Mail" ] ,
   ".youthhostel.ch>" : [ "youthhostel_ch.png" , "http://www.youthhostel.ch/" , "Swiss Youthhostels" ] ,
   ".trendmicro.com>" : [ "trendmicro.png" , "http://www.trendmicro.com/" , "TrendMicro" ] ,
+  ".telenet-ops.be>" : [ "telenet_be.png" , "http://telenet.be/" , "Telenet" ] ,
   ".corp.yahoo.com>" : [ "yahoo-inc.png" , "http://info.yahoo.com/center/us/yahoo/" , "Yahoo! Inc" ] ,
   ".auckland.ac.nz>" : [ "uni_auckland.png" , "http://www.auckland.ac.nz/" , "The University of Auckland" ] ,
   ".altervista.org>" : [ "altervista.png" , "http://www.altervista.org/" , "alterVISTA" ] ,
@@ -93,6 +95,7 @@ dispMUA.arDispMUAAllocation["message-id"] =
   "@cn.last.fm>" : [ "last-fm.png" , "http://cn.last.fm/" , "Last.fm" ] ,
   ".udmedia.de>" : [ "udmedia_de.png" , "http://www.udmedia.de/" , "UD Media" ] ,
   ".tiscali.de>" : [ "tiscali_de.png" , "http://www.tiscali.de/" , "Tiscali Deutschland" ] ,
+  ".tipp24.net>" : [ "lotto.png" , "http://www.tipp24.com/" , "Tipp24" ] ,
   ".oracle.com>" : [ "oracle.png" , "http://www.oracle.com/" , "ORACLE" ] ,
   ".nabble.com>" : [ "nabble.png" , "http://www.nabble.com/" , "Nabble" ] ,
   ".google.com>" : [ "google.png" , "http://www.google.com/" , "Google" ] ,
@@ -113,11 +116,13 @@ dispMUA.arDispMUAAllocation["message-id"] =
   ".paypal.de>" : [ "paypal.png" , "http://www.paypal.de/" , "PayPal" ] ,
   ".orange.sk>" : [ "orange.png" , "http://www.orangeportal.sk/" , "Orange Slovensko" ] ,
   ".oleco.com>" : [ "oleco_com.png" , "http://www.oleco.com/" , "Oleco" ] ,
+  ".nestle.de>" : [ "nestle.png" , "http://www.nestle.de/" , "Nestle" ] ,
   ".libero.it>" : [ "libero_it.png" , "http://liberomail.libero.it/" , "libero.it" ] ,
   ".gmail.com>" : [ "google_gmail.png" , "http://www.gmail.com/" , "GMail" ] ,
   ".avira.com>" : [ "avira.png" , "http://www.avira.com/" , "Avira" ] ,
   ".apple.com>" : [ "apple.png" , "http://www.apple.com/" , "Apple" ] ,
   ".ampega.de>" : [ "ampega.png" , "http://www.ampegagerling.de/" , "ampegaGerling.de" ] ,
+  ".1and1.com>" : [ "1und1.png" , "http://www.1and1.com/" , "1&1" ] ,
   "@xmr3.com>" : [ "xmr3_com.png" , "http://www.xmr3.com/" , "messageReach" ] ,
   "@funke.de>" : [ "funke_de.png" , "http://www.funke.de/" , "FUNKE GmbH" ] ,
   "@be3a.com>" : [ "be3a.png" , "http://www.be3a.com/" , "B!3A" ] ,
@@ -151,6 +156,7 @@ dispMUA.arDispMUAAllocation["message-id"] =
   ".mail.ru>" : [ "mail_ru.png" , "http://www.mail.ru/" , "@mail.ru" ] ,
   ".mail.ee>" : [ "mail_ee.png" , "http://www.mail.ee/" , "Mail.ee" ] ,
   ".gmx.net>" : [ "gmx.png" , "http://www.gmx.net/" , "GMX" ] ,
+  ".ibm.com>" : [ "ibm.png" , "http://www.ibm.com/" , "IBM" ] ,
   ".chip.de>" : [ "chip_de.png" , "http://www.chip.de/" , "CHIP Online" ] ,
   ".cevi.be>" : [ "cevi_be.png" , "http://www.cevi.be/" , "Cevi NV" ] ,
   ".buch.de>" : [ "buch_de.png" , "http://www.buch.de/" , "buch.de" ] ,
